@@ -25,7 +25,8 @@ impl Repo {
     #[instrument(skip_all)]
     pub fn new(directory: impl AsRef<Path>) -> anyhow::Result<Self> {
         debug!("initializing directory {:?}", directory.as_ref());
-        let current_branch = Self::get_current_branch(&directory)?;
+        let current_branch =
+            Self::get_current_branch(&directory).context("cannot determine current branch")?;
 
         Ok(Self {
             directory: directory.as_ref().to_path_buf(),
@@ -68,8 +69,8 @@ impl Repo {
         Ok(())
     }
 
-    pub fn push(&self, branch: &str) -> anyhow::Result<()> {
-        self.git(&["push", "origin", branch])?;
+    pub fn push(&self, obj: &str) -> anyhow::Result<()> {
+        self.git(&["push", "origin", obj])?;
         Ok(())
     }
 
@@ -167,12 +168,23 @@ impl Repo {
     pub fn current_commit_message(&self) -> anyhow::Result<String> {
         self.git(&["log", "-1", "--pretty=format:%s"])
     }
+
+    pub fn tag(&self, name: &str) -> anyhow::Result<String> {
+        self.git(&["tag", name])
+    }
 }
 
 #[instrument]
 pub fn git_in_dir(dir: &Path, args: &[&str]) -> anyhow::Result<String> {
     let args: Vec<&str> = args.iter().map(|s| s.trim()).collect();
-    let output = Command::new("git").arg("-C").arg(dir).args(args).output()?;
+    let output = Command::new("git")
+        .arg("-C")
+        .arg(dir)
+        .args(&args)
+        .output()
+        .with_context(|| {
+            format!("error while running git in directory `{dir:?}` with args `{args:?}`")
+        })?;
     trace!("git output = {:?}", output);
     let stdout = cmd::string_from_bytes(output.stdout)?;
     if output.status.success() {
